@@ -16,8 +16,7 @@
  * along with this program.  If not, see <http://www.gnu.org/licenses/>.";
  */
 
-#ifndef __POLARI_DRAG_HELPER_H__
-#define __POLARI_DRAG_HELPER_H__
+#pragma once
 
 #include <gtk/gtk.h>
 
@@ -34,5 +33,3 @@ guint    polari_drag_dest_find_target (GtkWidget      *widget,
                                        GdkDragContext *context);
 
 G_END_DECLS
-
-#endif /* __POLARI_DRAG_HELPER_H__ */
