@@ -1,7 +1,7 @@
-/* exported isFlatpakSandbox getTpEventTime findUrls findChannels openURL
+/* exported isFlatpakSandbox touchFile needsOnetimeAction getTpEventTime
+            findUrls findChannels openURL updateTerms gpaste imgurPaste
             storeAccountPassword storeIdentifyPassword
             lookupAccountPassword lookupIdentifyPassword
-            updateTerms gpaste imgurPaste
             clearAccountPassword clearIdentifyPassword */
 /*
  * Copyright (c) 2011 Red Hat, Inc.
@@ -30,13 +30,13 @@ const { Gdk, Gio, GLib, Gtk, Secret, Soup, TelepathyGLib: Tp }  = imports.gi;
 const AppNotifications = imports.appNotifications;
 
 const SECRET_SCHEMA_ACCOUNT = new Secret.Schema(
-    'org.gnome.Polari.Account', Secret.SchemaFlags.NONE,
-    { 'account-id': Secret.SchemaAttributeType.STRING }
-);
+    'org.gnome.Polari.Account',
+    Secret.SchemaFlags.NONE,
+    { 'account-id': Secret.SchemaAttributeType.STRING });
 const SECRET_SCHEMA_IDENTIFY = new Secret.Schema(
-    'org.gnome.Polari.Identify', Secret.SchemaFlags.NONE,
-    { 'account-id': Secret.SchemaAttributeType.STRING }
-);
+    'org.gnome.Polari.Identify',
+    Secret.SchemaFlags.NONE,
+    { 'account-id': Secret.SchemaAttributeType.STRING });
 
 const GPASTE_BASEURL = 'https://paste.gnome.org/';
 
@@ -94,6 +94,36 @@ function isFlatpakSandbox() {
     return _inFlatpakSandbox;
 }
 
+function touchFile(file) {
+    try {
+        file.get_parent().make_directory_with_parents(null);
+    } catch (e) {
+        if (!e.matches(Gio.IOErrorEnum, Gio.IOErrorEnum.EXISTS))
+            throw e;
+        // not an error, carry on
+    }
+
+    let stream = file.create(0, null);
+    stream.close(null);
+}
+
+function needsOnetimeAction(name) {
+    let path = GLib.build_filenamev([
+        GLib.get_user_data_dir(),
+        'polari',
+        `${name}-completed`,
+    ]);
+    let file = Gio.File.new_for_path(path);
+    try {
+        touchFile(file);
+    } catch (e) {
+        if (e.matches(Gio.IOErrorEnum, Gio.IOErrorEnum.EXISTS))
+            return false;
+        log(`Failed to mark onetime action ${name} as completed: ${e.message}`);
+    }
+    return true;
+}
+
 function getTpEventTime() {
     let time = Gtk.get_current_event_time();
     if (time === 0)
